@@ -15,15 +15,12 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-import sys
 
 import grokmirror
 import logging
 import fnmatch
 import subprocess
 
-from git import Repo
-
 logger = logging.getLogger(__name__)
 
 
@@ -33,10 +30,10 @@ def git_rev_parse_all(gitdir):
 
     if error:
         # Put things we recognize into debug
-        debug = []
-        warn = []
+        debug = list()
+        warn = list()
         for line in error.split('\n'):
-                warn.append(line)
+            warn.append(line)
         if debug:
             logger.debug('Stderr: %s', '\n'.join(debug))
         if warn:
@@ -50,8 +47,8 @@ def git_remote_update(args, fullpath):
 
     if error:
         # Put things we recognize into debug
-        debug = []
-        warn = []
+        debug = list()
+        warn = list()
         for line in error.split('\n'):
             if line.find('From ') == 0:
                 debug.append(line)
@@ -68,13 +65,7 @@ def git_remote_update(args, fullpath):
 def dumb_pull_repo(gitdir, remotes, svn=False):
     # verify it's a git repo and fetch all remotes
     logger.debug('Will pull %s with following remotes: %s', gitdir, remotes)
-    try:
-        repo = Repo(gitdir)
-        assert repo.bare is True
-    except:
-        logger.critical('Error opening %s.', gitdir)
-        logger.critical('Make sure it is a bare git repository.')
-        sys.exit(1)
+    old_revs = git_rev_parse_all(gitdir)
 
     try:
         grokmirror.lock_repo(gitdir, nonblocking=True)
@@ -83,8 +74,6 @@ def dumb_pull_repo(gitdir, remotes, svn=False):
         logger.info('\tAssuming another process is running.')
         return False
 
-    old_revs = git_rev_parse_all(gitdir)
-
     if svn:
         logger.debug('Using git-svn for %s', gitdir)
 
@@ -99,27 +88,25 @@ def dumb_pull_repo(gitdir, remotes, svn=False):
 
     else:
         # Not an svn remote
-        hasremotes = repo.git.remote()
-        if not len(hasremotes.strip()):
+        myremotes = grokmirror.list_repo_remotes(gitdir)
+        if not len(myremotes):
             logger.info('Repository %s has no defined remotes!', gitdir)
             return False
 
-        logger.debug('existing remotes: %s', hasremotes)
+        logger.debug('existing remotes: %s', myremotes)
         for remote in remotes:
             remotefound = False
-            for hasremote in hasremotes.split('\n'):
-                if fnmatch.fnmatch(hasremote, remote):
+            for myremote in myremotes:
+                if fnmatch.fnmatch(myremote, remote):
                     remotefound = True
-                    logger.debug('existing remote %s matches %s',
-                                 hasremote, remote)
-                    args = ['remote', 'update', hasremote]
-                    logger.info('Updating remote %s in %s', hasremote, gitdir)
+                    logger.debug('existing remote %s matches %s', myremote, remote)
+                    args = ['remote', 'update', myremote, '--prune']
+                    logger.info('Updating remote %s in %s', myremote, gitdir)
 
                     git_remote_update(args, gitdir)
 
             if not remotefound:
-                logger.info('Could not find any remotes matching %s in %s',
-                            remote, gitdir)
+                logger.info('Could not find any remotes matching %s in %s', remote, gitdir)
 
     new_revs = git_rev_parse_all(gitdir)
     grokmirror.unlock_repo(gitdir)
@@ -141,8 +128,7 @@ def run_post_update_hook(hookscript, gitdir):
 
     args = [hookscript, gitdir]
     logger.debug('Running: %s', ' '.join(args))
-    (output, error) = subprocess.Popen(args, stdout=subprocess.PIPE,
-                                       stderr=subprocess.PIPE).communicate()
+    (output, error) = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
 
     error = error.decode().strip()
     output = output.decode().strip()
@@ -155,72 +141,49 @@ def run_post_update_hook(hookscript, gitdir):
 
 
 def parse_args():
-    from optparse import OptionParser
+    import argparse
+    # noinspection PyTypeChecker
+    op = argparse.ArgumentParser(prog='grok-dumb-pull',
+                                 description='Fetch remotes in repositories not managed by grokmirror',
+                                 formatter_class=argparse.ArgumentDefaultsHelpFormatter)
 
-    usage = '''usage: %prog [options] /path/to/repos
-    Bluntly fetch remotes in specified git repositories.
-    '''
+    op.add_argument('-v', '--verbose', dest='verbose', action='store_true',
+                    default=False,
+                    help='Be verbose and tell us what you are doing')
+    op.add_argument('-s', '--svn', dest='svn', action='store_true',
+                    default=False,
+                    help='The remotes for these repositories are Subversion')
+    op.add_argument('-r', '--remote-names', dest='remotes', action='append',
+                    default=None,
+                    help='Only fetch remotes matching this name (accepts shell globbing)')
+    op.add_argument('-u', '--post-update-hook', dest='posthook',
+                    default='',
+                    help='Run this hook after each repository is updated.')
+    op.add_argument('-l', '--logfile', dest='logfile',
+                    default=None,
+                    help='Put debug logs into this file')
+    op.add_argument('--version', action='version', version=grokmirror.VERSION)
+    op.add_argument('paths', nargs='+', help='Full path(s) of the repos to pull')
 
-    op = OptionParser(usage=usage, version=grokmirror.VERSION)
-    op.add_option('-v', '--verbose', dest='verbose', action='store_true',
-                  default=False,
-                  help='Be verbose and tell us what you are doing')
-    op.add_option('-s', '--svn', dest='svn', action='store_true',
-                  default=False,
-                  help='The remotes for these repositories are Subversion')
-    op.add_option('-r', '--remote-names', dest='remotes', action='append',
-                  default=[],
-                  help='Only fetch remotes matching this name (accepts '
-                       'shell globbing, can be passed multiple times)')
-    op.add_option('-u', '--post-update-hook', dest='posthook',
-                  default='',
-                  help='Run this hook after each repository is updated. Passes '
-                       'full path to the repository as the sole argument.')
-    op.add_option('-l', '--logfile', dest='logfile',
-                  default=None,
-                  help='Put debug logs into this file')
+    opts = op.parse_args()
 
-    opts, args = op.parse_args()
-
-    if not len(args):
+    if not len(opts.paths):
         op.error('You must provide at least a path to the repos to pull')
 
-    return opts, args
+    return opts
 
 
-def dumb_pull(args, verbose=False, svn=False, remotes=None, posthook='',
-              logfile=None):
+def dumb_pull(paths, verbose=False, svn=False, remotes=None, posthook='', logfile=None):
+    global logger
+
+    loglevel = logging.INFO
+    logger = grokmirror.init_logger('dumb-pull', logfile, loglevel, verbose)
 
     if remotes is None:
         remotes = ['*']
 
-    logger.setLevel(logging.DEBUG)
-
-    ch = logging.StreamHandler()
-    formatter = logging.Formatter('%(message)s')
-    ch.setFormatter(formatter)
-
-    if verbose:
-        ch.setLevel(logging.INFO)
-    else:
-        ch.setLevel(logging.CRITICAL)
-
-    logger.addHandler(ch)
-
-    if logfile is not None:
-        ch = logging.FileHandler(logfile)
-        formatter = logging.Formatter(
-            "[%(process)d] %(asctime)s - %(levelname)s - %(message)s")
-        ch.setFormatter(formatter)
-
-        ch.setLevel(logging.DEBUG)
-        logger.addHandler(ch)
-
-    # push our logger into grokmirror to override the default
-    grokmirror.logger = logger
-
     # Find all repositories we are to pull
-    for entry in args:
+    for entry in paths:
         if entry[-4:] == '.git':
             if not os.path.exists(entry):
                 logger.critical('%s does not exist', entry)
@@ -240,11 +203,10 @@ def dumb_pull(args, verbose=False, svn=False, remotes=None, posthook='',
 
 
 def command():
-
-    opts, args = parse_args()
+    opts = parse_args()
 
     return dumb_pull(
-        args, verbose=opts.verbose, svn=opts.svn, remotes=opts.remotes,
+        opts.paths, verbose=opts.verbose, svn=opts.svn, remotes=opts.remotes,
         posthook=opts.posthook, logfile=opts.logfile)
 
 
